#
# spec file for package python-configshell-fb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-configshell-fb
Version:        1.1.30
Release:        2.3
Summary:        A Python library for building configuration shells
License:        Apache-2.0
Group:          Development/Libraries/Python
URL:            https://github.com/open-iscsi/configshell-fb
Source:         %{name}-%{version}.tar.xz
#PATCH-FIX-UPSTREAM https://github.com/open-iscsi/configshell-fb/pull/74 six is unneeded
Patch:          no-six.patch
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       %{_bindir}/env
Requires:       python-pyparsing
Requires:       python-urwid
Provides:       python-configshell = %{version}-%{release}
Obsoletes:      python-configshell < %{version}
BuildArch:      noarch
%python_subpackages

%description
configshell-fb is a Python library that provides a framework for building simple
but nice CLI-based applications.

configshell-fb is a fork of the "configshell" code written by RisingTide
Systems. The "-fb" differentiates between the original and this version. Please
ensure to use either all "fb" versions of the targetcli components -- targetcli,
rtslib, and configshell, or stick with all non-fb versions, since they are
no longer strictly compatible.

%package doc
Summary:        Documentation for Python configshell-fb
Group:          Documentation/HTML

%description doc
configshell-fb is a Python library that provides a framework for building simple
but nice CLI-based applications.

configshell-fb is a fork of the "configshell" code written by RisingTide
Systems. The "-fb" differentiates between the original and this version. Please
ensure to use either all "fb" versions of the targetcli components -- targetcli,
rtslib, and configshell, or stick with all non-fb versions, since they are
no longer strictly compatible.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%python_build

%install
%python_install --skip-build
%fdupes %{buildroot}

%files %{python_files}
%{python_sitelib}/configshell
%{python_sitelib}/configshell_fb
%{python_sitelib}/configshell_fb-%{version}*info
%doc README.md

%changelog
* Tue Apr 16 2024 Markéta Machová <mmachova@suse.com>
- Add no-six.patch to get rid of unneeded six dependency
* Sun Jul  2 2023 Lee Duncan <lduncan@suse.com>
- Upgrade to latest upstream version v1.1.30:
  * setup.py: relax pyparsing version restriction
  * Replace more occurrences of getargspec() with getfullargspec()
  * replace getargspec() with getfullargspec()
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Sun Sep 19 2021 Lee Duncan <lduncan@suse.com>
- Upgrade to latest upstream version v1.1.29 (jre#SLE-17360):
  * setup.py: specify a version range for pyparsing
  * setup.py: lets stick to pyparsing v2.4.7
  * Don't warn if prefs file doesn't exist
* Sat Jan 30 2021 Lee Duncan <lduncan@suse.com>
- Update to version v1.1.28 from v1.1.27 (jre#SLE-17360):
  * version 1.1.28
  * Ensure that all output reaches the client when daemonized
  * Remove Epydoc markup from command messages
  * Remove epydoc imports and epydoc calls
  Which removed the need for patch:
  * Ensure-that-all-output-reaches-the-client-when-daemo.patch
* Tue Mar  3 2020 lduncan@suse.com
- Update to version v1.1.27 from v1.1.26 (jre#SLE-7751):
  * version 1.1.27
  * Use pyparsing's locatedExpr instead of our custom helper
  And updated the SPEC file, also adding a _service file.
  Replacing configshell-fb-1.1.26.tar.gz with
  python-configshell-fb-v1.1.27.tar.xz, and adding one
  upstrem patch:
  * Ensure-that-all-output-reaches-the-client-when-daemo.patch
* Mon Sep 16 2019 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream version 1.1.26. There were not very
  many changes:
  * Version number no longer contains "fb" to designate "free
    branch", e.g. old was 1.1.fb25, new is 1.1.26
  * Add urwid to setup.py dependencies
  * Fix failing to parse params with additional chars
  * export __version__ variable
  resulting in replacing configshell-fb-1.1.25.tar.gz with
  configshell-fb-1.1.26.tar.gz, and corresponding SPEC-file
  updates.
* Fri Mar  8 2019 Matej Cepl <mcepl@suse.com>
- Using now new proper upstream release 1.1.25:
  - Fix failing to parse param like pool/rbd;id=user
  - Acquire a lock to a preference file before working with it
  - Fix failing to pasre param like "cfgstr,par=val"
  - Remove explicit dependency on /usr/bin/python
  - make run_cmdline() log "Running command line" msg to new loglevel
  - tweak ConfigShell.run_stdin() to strip whitespace/newline from cmds
  - Fix failing to pasre par=val parameters
  - Add missing dependency on pyparsing and six
  - Fix path regex for [ and ]
  - Handle if TERM is not set
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Oct 18 2018 opensuse-packaging@opensuse.org
- Update to version 1.1.fb23:
  * version 1.1.25
  * Fix failing to parse param like pool/rbd;id=user
  * Acquire a lock to a preference file before working with it
  * Fix failing to pasre param like "cfgstr,par=val"
  * version 1.1.fb24
  * Remove explicit dependency on /usr/bin/python
  * make run_cmdline() log "Running command line" msg to new loglevel
  * tweak ConfigShell.run_stdin() to strip whitespace/newline from cmds
  * Fix failing to pasre par=val parameters
  * Add missing dependency on pyparsing and six
  * Fix path regex for [ and ]
  * Handle if TERM is not set
  Replacing configshell-fb-1.1.fb23.tar.xz with configshell-fb-1.1.fb25.tar.xz,
  and updating the SPEC file. Also, two patches subsumed/removed:
  * configshell-fb-example-should-not-specify-path.patch
  * configshell-fb-Handle-if-TERM-is-not-set.patch
* Sun Feb 25 2018 olaf@aepfle.de
- Fix upgrade path by provide/obsolete python-configshell (bsc#1082693)
* Wed Jan  3 2018 tchvatal@suse.com
- Do not build epydoc documentation to allow py3 only build
* Fri Dec  8 2017 lduncan@suse.com
- Converting RPM SPEC file to singlespec format (bsc#1045332),
  adding patch:
  * configshell-fb-example-should-not-specify-path.patch
- Fix targetcli.service problem when TERM not set (bsc#1071194),
  adding patch (from LSZhu):
  * configshell-fb-Handle-if-TERM-is-not-set.patch
- Moved build requirement on urwid to runtime requirement,
  as suggested by scarabeus_iv
- ran spec-cleaner to clean up SPEC file
- Converted from manually-added configshell-fb tar file to
  tar_scm service-generated file by adding _service and
  _servicedata
* Thu Aug 17 2017 lszhu@suse.com
- Update to version 1.1.23fb
  * improving ALUA and TCMU support
* Mon Feb 27 2017 shshyukriev@suse.com
- Update to v 1.1.22fb
  * Fixed github source namespace
* Fri Jun 24 2016 lduncan@suse.com
- Updated spec file: added Conflicts for python-configshell
  (bsc#986475)
* Fri Jun 24 2016 lduncan@suse.com
- Updated SPEC file: removed "Provides"/"Obsoletes" for
  package name "python-confishell" (bsc#984935)
* Fri May  6 2016 dmueller@suse.com
- cleanup buildroot parts
* Tue Apr 19 2016 lduncan@suse.com
- Initial creation of this package, from upstream
  version 1.1.fb20
